"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@serverless-cd/core");
const child_process_1 = require("child_process");
function setup(props, logger) {
    const alias = core_1.lodash.get(props, 'alias', 'default');
    const credentials = core_1.lodash.get(props, 'credentials', {});
    if (core_1.lodash.isEmpty(credentials)) {
        throw new Error('Failed to setup Serverless Devs');
    }
    try {
        checkDevs(logger);
    }
    catch (_e) {
        logger.debug('Attempt to install devs...');
        (0, child_process_1.spawnSync)('npm install @serverless-devs/s -g', { shell: true, encoding: 'utf8' });
        logger.debug('Attempt to install devs end. Retry check s');
        checkDevs(logger);
    }
    let runCommond = `s config add --AccessKeyID "${credentials.accessKeyId}" --AccessKeySecret "${credentials.accessKeySecret}"`;
    if (credentials.accountId) {
        runCommond = `${runCommond} --AccountID ${credentials.accountId}`;
    }
    if (credentials.securityToken) {
        runCommond = `${runCommond} --SecurityToken "${credentials.securityToken}"`;
    }
    runCommond = `${runCommond} --access "${alias}" -f`;
    logger.debug(`Run s add commond: ${runCommond}`);
    const addRes = (0, child_process_1.spawnSync)(runCommond, { shell: true, encoding: 'utf8' });
    logger.info(addRes.stdout);
    if (addRes.stderr) {
        logger.error(addRes.stderr);
    }
}
exports.default = setup;
function checkDevs(logger) {
    const { status, stdout, stderr } = (0, child_process_1.spawnSync)('s --version', { shell: true, encoding: 'utf8' });
    logger.debug(`Run s --version status: ${status}`);
    logger.debug(`Run s --version stdout: ${stdout}`);
    if (stderr) {
        logger.error(`Run s --version stderr: ${stderr}`);
    }
    if (status !== 0) {
        throw new Error('Serverless Devs is not installed');
    }
}
//# sourceMappingURL=setup.js.map